#
# spec file for package mgetty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mgetty
Version:        1.2.1
Release:        10.2
Summary:        Mgetty Listens for Data, Fax, or Voice Calls on a Serial Line
License:        GPL-2.0-or-later
Group:          Hardware/Fax
URL:            http://mgetty.greenie.net/
Source0:        ftp://mgetty.greenie.net/pub/mgetty/source/1.2/mgetty-%{version}.tar.gz
Source2:        logrotate
Source3:        mgetty@.service
Source4:        vgetty@.service
Patch0:         mgetty-1.1.37-makefile.patch
Patch1:         mgetty-1.1.36-local.patch
Patch2:         mgetty-1.1.36-tempfile.patch
Patch3:         mgetty-1.1.37-callback.patch
Patch4:         mgetty-1.1.36-specialdigits.patch
Patch5:         mgetty-1.1.36-implicit-fortify-decl.patch
Patch6:         mgetty-1.1.36-no-date-time.patch
Patch7:         bug646280.patch
Patch8:         fixpie.patch
Patch9:         lp64.patch
Patch10:        mgetty-1.1.36-fix-bashisms.patch
Patch12:        mgetty-noroot.patch
Patch13:        mgetty-mkdir-p.patch
Patch14:        mgetty-fix-errlist.patch
Patch15:        faxq-libexec.patch
BuildRequires:  groff
BuildRequires:  makeinfo
BuildRequires:  netpbm
BuildRequires:  systemd-rpm-macros
Requires:       g3utils
Requires(post): %{install_info_prereq}
Requires(postun): %{install_info_prereq}
Recommends:     logrotate
%systemd_requires

%description
This package turns your computer into a fax machine. With some voice
modems (Zyxel, Rockwell, and USR), you can even use your computer as an
answering machine.

Mgetty recognizes what kind of call it is receiving and does everything
else automatically. It is able to accept data (login/PPP), fax, and
(depending on your modem) voice calls. Find the documentation in
%{_docdir}/mgetty and TeX Info files in %{_datadir}/info.

The configuration files are in %{_sysconfdir}/mgetty+sendfax.

%package -n sendfax
Summary:        A Tool for Sending Fax Documents
Group:          Hardware/Fax
Requires:       g3utils
Requires:       mgetty
Requires(pre):  group(uucp)
Requires(pre):  permissions
Requires(pre):  shadow
Conflicts:      hylafax
Provides:       fax_daemon
Provides:       user(fax)

%description -n sendfax
The sendfax part of mgetty. You can use it instead of hylafax for
sending faxes. The sources are included in the mgetty source package.

%package -n g3utils
Summary:        Tools for the G3 (Fax) Graphics Format
Group:          Productivity/Graphics/Convertors

%description -n g3utils
These utilities convert graphics files from the G3 format into the
general- purpose PBM format and back, so you can print or manipulate
them. G3 is used by fax modems and machines.

The g3utils are included in the mgetty source package.

%prep
%setup -q
%patch -P 0
%patch -P 1
%patch -P 2
%patch -P 3 -p1
%patch -P 4
%patch -P 5
%patch -P 6
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
%patch -P 10 -p1
%patch -P 12 -p1
%patch -P 13 -p1
%patch -P 14 -p1
%patch -P 15 -p1
chmod +x mkidirs

%build
ln -s policy.h-dist policy.h
%make_build -j1 CFLAGS="%{optflags} -fPIE -DAUTO_PPP" LDFLAGS="-pie" CC="gcc"
%make_build -j1 -C voice CFLAGS="%{optflags} -fPIE -DAUTO_PPP" LDFLAGS="-pie" CC="gcc"

%install
%make_install
install samples/new_fax.mail %{buildroot}%{_sysconfdir}/mgetty+sendfax/new_fax
ln -sf ../../..%{_sysconfdir}/mgetty+sendfax/new_fax %{buildroot}%{_prefix}/lib/mgetty+sendfax/
make install -C voice DESTDIR=%{buildroot}
install -m 644 voice/voice.conf-dist %{buildroot}%{_sysconfdir}/mgetty+sendfax/voice.conf
mkdir -p %{buildroot}%{_localstatedir}/spool/voice/{incoming,messages} %{buildroot}%{_docdir}/mgetty/voice
install -m 644 [BFRT]* doc/ttyS-cua.txt %{buildroot}%{_docdir}/mgetty/
install -m 644 voice/[ART]* voice/doc/* %{buildroot}%{_docdir}/mgetty/voice/
mkdir -p %{buildroot}%{_docdir}/mgetty/samples
for name in samples/*; do if test ! -d $name; then install -m644 $name %{buildroot}%{_docdir}/mgetty/samples; fi; done
mkdir -p %{buildroot}%{_docdir}/mgetty/samples/new_fax.all
install -m 644 samples/new_fax.all/* %{buildroot}%{_docdir}/mgetty/samples/new_fax.all/
cd voice && cp -R scripts %{buildroot}%{_docdir}/mgetty/voice/
chmod 644 %{buildroot}%{_docdir}/mgetty/voice/scripts/*
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/mgetty
install -D -m 0644  %{SOURCE3} %{buildroot}/%{_unitdir}/mgetty@.service
install -D -m 0644  %{SOURCE4} %{buildroot}/%{_unitdir}/vgetty@.service

%pre -n sendfax
%{_sbindir}/useradd -r -o -g uucp -u 33 -s /bin/bash -c "Facsimile agent" -d %{_localstatedir}/spool/fax fax 2> /dev/null || :
/bin/touch %{_localstatedir}/log/sendfax.log
chown fax:uucp %{_localstatedir}/log/sendfax.log
chmod 664 %{_localstatedir}/log/sendfax.log

%post -n sendfax
%set_permissions  %{_localstatedir}/spool/fax/outgoing %{_libexecdir}/mgetty+sendfax/faxq-helper

%verifyscript -n sendfax
%verify_permissions -e %{_localstatedir}/spool/fax/outgoing -e %{_libexecdir}/mgetty+sendfax/faxq-helper

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files
%dir %{_sysconfdir}/mgetty+sendfax
%doc %{_docdir}/mgetty
%dir %{_localstatedir}/spool/voice
%dir %{_localstatedir}/spool/voice/incoming
%dir %{_localstatedir}/spool/voice/messages
%{_unitdir}/mgetty@.service
%{_unitdir}/vgetty@.service
%config(noreplace) %{_sysconfdir}/logrotate.d/mgetty
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/dialin.config
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/login.config
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/mgetty.config
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/voice.conf
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/callback.config
%{_bindir}/autopvf
%{_bindir}/basictopvf
%{_bindir}/lintopvf
%{_bindir}/newslock
%{_bindir}/pvfamp
%{_bindir}/pvfcut
%{_bindir}/pvfecho
%{_bindir}/pvffft
%{_bindir}/pvffile
%{_bindir}/pvffilter
%{_bindir}/pvfmix
%{_bindir}/pvfnoise
%{_bindir}/pvfreverse
%{_bindir}/pvfsine
%{_bindir}/pvfspeed
%{_bindir}/pvftoau
%{_bindir}/pvftobasic
%{_bindir}/pvftolin
%{_bindir}/pvftormd
%{_bindir}/pvftovoc
%{_bindir}/pvftowav
%{_bindir}/rmdfile
%{_bindir}/rmdtopvf
%{_bindir}/sff2g3
%{_bindir}/vm
%{_bindir}/voctopvf
%{_bindir}/wavtopvf
%{_infodir}/mgetty.info*%{ext_info}
%{_mandir}/man1/autopvf.1%{?ext_man}
%{_mandir}/man1/basictopvf.1%{?ext_man}
%{_mandir}/man1/lintopvf.1%{?ext_man}
%{_mandir}/man1/pvf.1%{?ext_man}
%{_mandir}/man1/pvfamp.1%{?ext_man}
%{_mandir}/man1/pvfcut.1%{?ext_man}
%{_mandir}/man1/pvfecho.1%{?ext_man}
%{_mandir}/man1/pvffft.1%{?ext_man}
%{_mandir}/man1/pvffile.1%{?ext_man}
%{_mandir}/man1/pvffilter.1%{?ext_man}
%{_mandir}/man1/pvfmix.1%{?ext_man}
%{_mandir}/man1/pvfnoise.1%{?ext_man}
%{_mandir}/man1/pvfreverse.1%{?ext_man}
%{_mandir}/man1/pvfsine.1%{?ext_man}
%{_mandir}/man1/pvfspeed.1%{?ext_man}
%{_mandir}/man1/pvftoau.1%{?ext_man}
%{_mandir}/man1/pvftobasic.1%{?ext_man}
%{_mandir}/man1/pvftolin.1%{?ext_man}
%{_mandir}/man1/pvftormd.1%{?ext_man}
%{_mandir}/man1/pvftovoc.1%{?ext_man}
%{_mandir}/man1/pvftowav.1%{?ext_man}
%{_mandir}/man1/sff2g3.1%{?ext_man}
%{_mandir}/man1/rmdfile.1%{?ext_man}
%{_mandir}/man1/rmdtopvf.1%{?ext_man}
%{_mandir}/man1/voctopvf.1%{?ext_man}
%{_mandir}/man1/wavtopvf.1%{?ext_man}
%{_mandir}/man1/zplay.1%{?ext_man}
%{_mandir}/man4/mgettydefs.4%{?ext_man}
%{_mandir}/man8/callback.8%{?ext_man}
%{_mandir}/man8/faxq-helper.8%{?ext_man}
%{_mandir}/man8/mgetty.8%{?ext_man}
%{_mandir}/man8/vgetty.8%{?ext_man}
%{_sbindir}/mgetty
%{_sbindir}/vgetty
%{_sbindir}/callback
# Note: This was erroneously in sendfax subpackage and the %config was missing
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/new_fax
%config %{_prefix}/lib/mgetty+sendfax/new_fax

%files -n g3utils
%{_bindir}/g32pbm
%{_bindir}/g3cat
%{_bindir}/g3topbm
%{_bindir}/pbm2g3
%{_mandir}/man1/g32pbm.1%{?ext_man}
%{_mandir}/man1/g3cat.1%{?ext_man}
%{_mandir}/man1/pbm2g3.1%{?ext_man}

%files -n sendfax
%dir %{_sysconfdir}/mgetty+sendfax
%dir %{_prefix}/lib/mgetty+sendfax
%{_libexecdir}/mgetty+sendfax
%attr(755,fax,root) %dir %{_localstatedir}/spool/fax
%dir %{_localstatedir}/spool/fax/incoming
%attr(755,fax,root) %verify(not mode) %dir %{_localstatedir}/spool/fax/outgoing
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/faxheader
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/faxrunq.config
%config(noreplace) %{_sysconfdir}/mgetty+sendfax/sendfax.config
%config %{_sysconfdir}/mgetty+sendfax/faxspool.rules.sample
%{_bindir}/faxq
%{_bindir}/faxrm
%{_bindir}/faxrunq
%{_bindir}/faxspool
%{_sbindir}/faxrunqd
%{_sbindir}/sendfax
%attr(4750,fax,trusted) %verify(not mode group) %{_libexecdir}/mgetty+sendfax/faxq-helper
%{_prefix}/lib/mgetty+sendfax/cour25.pbm
%{_prefix}/lib/mgetty+sendfax/cour25n.pbm
%{_mandir}/man1/fax.1%{?ext_man}
%{_mandir}/man1/faxq.1%{?ext_man}
%{_mandir}/man1/faxrm.1%{?ext_man}
%{_mandir}/man1/faxrunq.1%{?ext_man}
%{_mandir}/man1/faxspool.1%{?ext_man}
%{_mandir}/man1/coverpg.1%{?ext_man}
%{_mandir}/man5/faxqueue.5%{?ext_man}
%{_mandir}/man8/faxrunqd.8%{?ext_man}
%{_mandir}/man8/sendfax.8%{?ext_man}

%changelog
* Wed Mar 27 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Provide user(fax) in sendfax package. [bsc#1221420]
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Dec 16 2022 pgajdos@suse.com
- do not enable/disable parametrized service [bsc#914661c17]
* Tue Feb 22 2022 Martin Hauke <mardnh@gmx.de>
- Restore AutoPPP functionality by properly passing "-DAUTO_PPP"
  to CFLAGS.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * mgetty@.service
  * vgetty@.service
* Thu Jun 24 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- add faxq-libexec.patch: adjust buildsystem to move faxq-helper setuid binary
  to /usr/libexec (bsc#1171164)
* Tue May 25 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Link /usr/bin/newslock as PIE (bsc#1184124).
  - Modified fixpie.patch
* Tue Mar 16 2021 Marcus Meissner <meissner@suse.com>
- mgetty-fix-errlist.patch: just use strerror() here.
* Tue May 26 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- fix set_permissions invocation, a '%%' was missing for the faxq-helper path,
  causing the path never to be adjusted correctly during %%post.
* Wed Feb 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.2.1
  Changes from 1.1.37 to 1.2.0:
  * policy.h: default MAILER to "/usr/sbin/sendmail"
  * conf_mg.c, conf_mg.h, mgetty.c: new option "open-delay <msec>"
  * utmp.c, mg_utmp.h: apply FreeBSD port patches to adjust to 9.x
  * bug fixes based on static code analysis (mem leaks, buffer overruns)
  * mgetty.c: make "dialout!" logging more useful (log dialout command)
  * more bugfixes, features and code improvements
  * see ftp://mgetty.greenie.net/pub/mgetty/source/1.2/mgetty-1.1.37-1.2.0.diff.gz
  Changes from 1.2.0 to 1.2.1:
  * fax/faxrunq.in, fax/faxq.in: properly quote input from JOB files,
    avoid attack with shell metacharacters (CVE-2018-16741, bsc#1108752)
  * contrib/scrtsc.c: remove from distribution (CVE-2018-16742, bsc#1108762)
  * contrib/next-login/next-login.c: fix buffer overflow on username
    (CVE-2018-16743, bsc#1108761)
  * faxrec.c, policy.h: rework mail handling, avoid potential buffer
    overrun by means of "mail-to" config variable (CVE-2018-16744, bsc#1108757)
  * more bugfixes
  * see ftp://mgetty.greenie.net/pub/mgetty/source/1.2/mgetty-1.2.0-1.2.1.diff.gz
- Drop upstreamed patch 0001-Fix-build-failure-with-gcc-7.patch
- Reapplied patch mgetty-1.1.37-makefile.patch
* Mon Jan 27 2020 Marcus Meissner <meissner@suse.com>
- Fixed permission handling of faxq-helper. (bsc#1168170)
  - It is fax:trusted       4750 in "secure" mode.
  - Also is being checked and set correctly now.
* Wed Jun  7 2017 sbrabec@suse.com
- Update to version 1.1.37:
  * faxspool: implement "-t hh:mm-hh:mm" time-range syntax, add
  @DATE +<format>@ to faxheader processing
  * faxq: properly display queued jobs with time-range field
  * faxrunqd: correctly handle jobs running out of the end of their
  sent-time window.
  INCOMPATIBLE CHANGE: Changes handling of "-t hh:mm" to
  "from hh:mm to midnight"
  * microcom: improve read-from-device exception handling
  * sendfax: send NSF frame on reception,
  new option reset-after-fail
  * faxrunqd: enhance and clarify per-modem statistics
- New build fixes (mgetty-noroot.patch, mgetty-mkdir-p.patch).
- Update patches
  (mgetty-1.1.36-callback.patch -> mgetty-1.1.37-callback.patch,
  mgetty-1.1.36-makefile.patch -> mgetty-1.1.37-makefile.patch).
* Mon Jun  5 2017 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
- Remove few rpmlint warnings and reduce the deps to contain only
  what is needed
- Add patch to build with gcc7 0001-Fix-build-failure-with-gcc-7.patch
  bsc#1041290
* Wed Oct 26 2016 kukuk@suse.de
- Add PreReq for group uucp to sendfax package
* Sat Feb 27 2016 mpluskal@suse.com
- Use correct permissions for unit files (boo#968571)
* Wed Jan 28 2015 mpluskal@suse.com
- Require systemd-rpm-macros instead of systemd for building
* Sat Jan 24 2015 mpluskal@suse.com
- Add mgetty@.service and vgetty@.service (boo#914661)
* Thu Nov 27 2014 Led <ledest@gmail.com>
- fix bashisms in faxback.sh script
- add patches:
  * mgetty-1.1.36-fix-bashisms.patch
* Tue Mar  5 2013 schwab@suse.de
- lp64.patch: Add support for future LP64 platforms
* Thu Jan 10 2013 dmueller@suse.com
- replace run_permissions call with set_permissions (bnc#764113)
* Tue Sep 11 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Fri Mar  9 2012 mweckbecker@suse.com
- fixpie.patch: Use LDFLAGS instead of CFLAGS to make building with
  PIE work properly
* Tue Jan 24 2012 prusnak@opensuse.org
- build with PIE [bnc#743151]
* Mon Dec 26 2011 coolo@suse.com
- don't package files twice
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Fri May 13 2011 gjhe@novell.com
- fix bug [bnc#646280],adjust faxspool to process pdf file using
  gs directly, do not use acroreader.
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not include build date in binaries
* Fri Nov  7 2008 prusnak@suse.cz
- alter tempfile.patch to reuse spooldir (CVE-2008-4936) [bnc#442596]
* Thu Oct  9 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
* Thu Aug  7 2008 prusnak@suse.cz
- updated to 1.1.36
  * faxsend.c: (optionally) insert 100 0-bytes at start of page, to
    help modems that have problems with the before-EOL timing (new USRs)
  * fax_lib.c: add new MQ_ bit for 0-padding
  * fax/faxrunqd.in: make wait() interruptible, avoid queue stalls
    if only one modem active and this modem has a very long job.
    Additionally, detect hung sendfax processes, and kill()' em.
  * faxlib.c: recognize modem ID for Blatzheim ISDN/hybrid modems
  * fax/faxrunqd.in: add functionality to run external scripts if
    the fax queue reaches a "high water mark" length, and if a given
    modem has more than <x> consecutive errors
  * doc/faxrunqd.8in: document new options
  * fax/faxspool.in: add @S@ for faxheader (replace with job id)
  * sendfax.c: for "failed transmitting", log #of pages successfully
    sent + #of retries (important for judging significance of errors)
  * conf_sf.c: add new sendfax option "-R <n>" to set "max_tries" value
  * doc/sendfax.8in: document -R
  * tools/README: update documentation, add "microcom"
  * class1lib.c: in fax1_send_frame(): make logging more uniform and
    easier to read.  Handle case of "NO CARRIER" after
    frame has been sent, and check for internal
    consistency regarding "we have carrier" vs. "use
    existing carrier" (ugly)
  * class1.c: on reception, don't try to send DIS when CSI frame
    couldn't be sent.  Log # of current re-try.
  * add exim4 documentation to frontends/mail2fax06/README
  * class1lib.c: check all fax_send() return values (in case flow
    control gets stuck, we might have a timeout in there)
  * class1.c: properly implement scan line time handling / byte padding
  * class1.c: implement re-training on TCF/FTT, including stepdown
  * class1lib.c: implement fax1_st_table[] for scan line time
    handling (bit ordering in DCS/DIS frames is just weird).
    Add scan time parameter to fax1_send_dcs()
  * fax/faxspool.rules: add conversion rules for .jpg and .doc
  * fax/faxrunqd.in: fix write combining bug with partially-sent jobs
  * voice/libvoice/*: sparc64 compatibility fixes (*int vs. *p_int)
  * voice/Makefile: pull in new object files (hyla_nsf.o, g3file.o)
  * g3file.c: implement first draft of generic G3 I/O module,
    including EOL padding
  * t/t_g3f_c.c, t/t_g3file.in: test routines for g3file.c
  * class1.c: change fax1_send_page() to use g3_send_file()
  * fax/faxspool.in: netpbm calls "giftoppm" now "giftopnm" -> adapt
  * frontends/mail2fax06/: implement new mail to fax conversion tool,
    in perl, using MIME::Parser, which will properly handle attachments
  * tools/microcom.c: add <stdlib.h> to fix missing prototype warnings
  * config.c: insert {} to silence over-eager compiler warnings
  * tio.c: change "static char[] tio_compilation_type" into "#ident"
    (get rid of "unused variable" warning, save a few bytes .data)
  * locks.c: get rid of "unused variable tries" compiler warning
  * hyla_nsf.c: add mgetty T.35 vendor code to table
  * mgetty has its own ITU T.35 vendor code now! [0x04 0x81 0x0e]
  * tools/mid.c: implement "-Q" (quick query)
  * faxlib.c: handle USR reporting format for NSF frames
  * fax/faxrunqd.in: fix quoting bug in `date` call (Klaus Weglehner)
  * hyla_nsf.c: import new set of tables from Hylafax NSF.c++
  * hyla_nsf.c, class1.c, class1.h: silence compiler complaints
  * config.h: cast return value of c_bool() to (boolean)
  * class1.c: hand off incoming NSF frames to decoder
  * faxlib.c: convert incoming NSF frames to binary, hand off to decoder
  * hyla_nsf.c: import NSF vendor tables + decoder from Hylafax
  * class1.c: fax1_send_page(): fix end-of-page handling, reorder
    sending of TSI and DCS to correctly handle RTP/RTN
  * class1.c: fax1_send_page(): properly use fax_send_swaptable[]
    (page sending works now, if receiver doesn't need padding)
  * class1.c: fax1_send_page(): fix first and last chunk of page data
    (digifax header wasn't skipped, and last chunk was lost)
  * class1.c: handle DCN in fax1_dial_and_phase_AB()
  * class1.c: add receive torture test (to sender), more logging
  * fax_lib.h: define CAN character (cancel, ctrl-x)
  * class1lib.c: fax1_receive_frame(): if waiting for start-of-frame
    already runs into timeout, don't even try to read
    end-of-frame modem response (robustness)
  * class1lib.c: tell modem (send CAN character) when we timeout
    after AT+FRH=n, to make sure recovering works
  * class1lib.c: don't query AT+FRH=?/+FTH=? carriers
  * */Makefile: move all "fullclean" extras into "clean" target,
    remove "make fullclean"
  * Makefile: for "make fullclean" or "distclean", just do "clean"
* Mon Jul  9 2007 jdelvare@suse.de
- added callback utility with sample config [#288227]
* Sat Apr 21 2007 aj@suse.de
- Use texlive for building.
* Fri Mar 30 2007 rguenther@suse.de
- add pwdutils to BuildRequires for postinst script invocation
* Thu Jan  4 2007 prusnak@suse.cz
- update to 1.1.35
  * added "faxq stop" and "faxq start" functionality
  * added destination number format (NDID=...) for Digi DataFire
  * decode & log receiver capabilities (+FDIS/+FIS)
  * make code robust against all sort of unexpected behaviours
- drop obsolete patches:
  * mgetty-1.1.33-overflow.diff
  * mgetty-1.1.33-printf.diff
* Sat Nov 11 2006 olh@suse.de
- fix doc file permissions
* Wed May 24 2006 schwab@suse.de
- Don't build as root.
- Don't strip binaries.
* Mon Feb 27 2006 anicka@suse.cz
- fix #151487 (printf problem)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug 11 2005 mmj@suse.de
- install the right logrotate file [#103789]
* Wed Aug  3 2005 mjancar@suse.cz
- update to 1.1.33
* Tue Jun 14 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
- fixed 1 single byte overflow (harmless)
* Tue Feb  8 2005 kkeil@suse.de
- allow '#' and '*' in faxspool phone numbers (#26060)
* Thu Jan 13 2005 pth@suse.de
- fix calls of trap in faxrunq.
* Thu Nov 11 2004 ro@suse.de
- permissions handling fixes (/var/spool/fax/outgoing)
* Tue Aug 10 2004 tcrhak@suse.cz
- update to 1.1.31
* Thu Apr  1 2004 kkeil@suse.de
- fix possible security problem in faxspool script (#36416)
* Wed Mar 17 2004 meissner@suse.de
- ported to ppc64
* Fri Dec 12 2003 schwab@suse.de
- Fix file list.
* Fri Sep 19 2003 kukuk@suse.de
- Add missing PreRequires
* Wed Sep 17 2003 kkeil@suse.de
- package must create sendfax.log since only root can do it(#31135)
* Wed Sep 17 2003 kukuk@suse.de
- sendfax should create fax user, not mgetty
* Tue Aug  5 2003 tcrhak@suse.cz
- run faxq-helper under user fax
- outgoing queue owned by fax
- fixed path to faxq-helper in scripts faxrm and faxq
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist (add missing binaries, info pages and directories)
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Feb 25 2003 tcrhak@suse.cz
- added dircategory and direntry tags to the texinfo file
  (patch direntry)
* Fri Feb 14 2003 tcrhak@suse.cz
- added install_info macros
* Thu Jan 23 2003 kkeil@suse.de
- create /etc/logrotate.d in buildroot
* Wed Jan 22 2003 tcrhak@suse.cz
- update to version 1.1.30
- added logrotate config to the package
* Sat Nov 23 2002 kkeil@suse.de
- varargs.h ---> stdarg.h for new GCC
* Tue May 21 2002 ro@suse.de
- recognize x86_64 as 64bit arch
* Fri Feb  1 2002 postadal@suse.cz
- fix specfile
* Wed Jan 30 2002 postadal@suse.cz
- Update to mgetty-1.1.28. (#9387)  Highlights:
  * patch to adapt to Linux/S390
  * add swedish ZyXEL caller ID format (T. Lundgren)
  * adaptions to OpenBSD
  * a lot of changes is in voice see voice/ChangeLog
* Thu Jul 26 2001 garloff@suse.de
- Move coverpg manpage to the sendfax subpackage.
- Update to mgetty-1.1.26. (#9387)  Highlights:
  * Better caller-ID handling
  * new viewfax
  * security precautions (O_EXCL, mkstemp)
  * Support multiple fax storage dirs
  * Voice support improved (0.9.27): Support
  - mu-law PCM (ZyXEL 2864)
  - Lucent-based Modem Blaster USB
  - V253modem (improvements)
  - internal modem MultiTech MT5634ZPX-PCI
  - Rockwell Spirit Cobra
  - TP560 Data/Fax/Voice 56K Modem / Supra56ePRO
  * ... and of course: many bugfixes
* Thu Mar  8 2001 garloff@suse.de
- tmpfile security fix shadowed file descriptor, thus causing
  failure of fax receiving. Thanks to Wilhelm Spickermann
  for reporting. (bugzilla #6641).
* Thu Dec  7 2000 garloff@suse.de
- Also include patch to fix paths from /usr/local to real places.
* Thu Dec  7 2000 garloff@suse.de
- tmpfile security fix (faxrecp)
* Thu Dec  7 2000 garloff@suse.de
- Update to 1.1.22-Aug17:
  * Inclusion of V.250/3 voice modem support
  * faxrunqd .last_run symlink vulnerability fixed
  * more bugfixes ...
* Tue Nov 28 2000 kukuk@suse.de
- Fix neededforbuild (libnetpb -> libnetpbm)
* Wed Sep 13 2000 schwab@suse.de
- Fix compilation on ia64.
* Thu Jun 29 2000 garloff@suse.de
- new_fax script moved to mgetty subpackage and marked %%(config)
  (Bug reported by Robert Griebl). Consequently moved to
  /etc/mgetty+sendfax/
- made most %%config files (noreplace)
* Tue May 23 2000 garloff@suse.de
- pbmtext hack removed.
- Install samples into %%{_docdir}/mgetty/samples.
* Mon May 22 2000 garloff@suse.de
- Fix RPM_BUILD_ROOT dir.
* Fri May 19 2000 garloff@suse.de
- Use BuildRoot.
- Get rid of Makefile.Linux
* Fri May 19 2000 garloff@suse.de
- Use macros for %%{_docdir} etc.
* Tue Feb 22 2000 garloff@suse.de
- merged ROs linux/types.h diff.
* Fri Feb 18 2000 garloff@suse.de
- Update to mgetty-1.1.21.
* Tue Jan 18 2000 ro@suse.de
- include linux/types before linux/serial
- man, info -> usr/share
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 20 1999 ro@suse.de
- sendfax: added Provides fax_daemon
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Sep  6 1999 garloff@suse.de
- created subpackage g3utils. Added home site to .spec
* Wed Mar 17 1999 ro@suse.de
- remove .orig with -f
* Mon Jan 25 1999 uli@suse.de
- update 1.1.18 -> 1.1.19
- fixed typo in frontends/dialog/faxv.in code
* Thu Oct  1 1998 ro@suse.de
- remove origs in voice/scripts
* Thu Oct  1 1998 ro@suse.de
- added tmp-fix for frontends/dialog/faxv.in
  and for voice/scripts/dtmf.sh (both from werner)
- voice/scripts removed local from shell-paths (/usr/bin/vm)
* Thu Oct  1 1998 ro@suse.de
- update to 1.1.18
* Thu Jul 23 1998 werner@suse.de
- Use mktemp for tmp files
* Tue Nov 11 1997 ro@suse.de
- sendfax builds from same spec
  pbmtext is copied from netpbm package
  fixed dependency to /usr/local/bin/vm
* Wed Jul 30 1997 florian@suse.de
- update to mgetty 1.1.8 (security fixes in sendfax scripts)
* Mon Jun  2 1997 florian@suse.de
- update to version 1.1.6
- make "sendfax.tgz" as an extra binary package
- include voice getty
- include pbmtext from netpbm, so you don't have to install the big
  netpbm package for using sendfax
* Thu Jan  2 1997 bs@suse.de
  recompiled with -DAUTO_PPP
* Thu Jan  2 1997 florian@suse.de
- update to 0.99.3
* Thu Jan  2 1997 florian@suse.de
- update to version 0.99.2
- config files are now in /etc/mgetty+sendfax
